# idc-index

```{toctree}
:maxdepth: 2
:hidden:
```

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

## Contents

```{toctree}
:maxdepth: 2
:titlesonly:
:caption: API docs

indices_reference
cli_tools.rst
api/idc_index
```

```{toctree}
:maxdepth: 2
:titlesonly:
:caption: Developer docs

dev/architecture
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
